@@ -20,7 +20,7 @@
 from __future__ import absolute_import
 from __future__ import with_statement
 
-VERSION = (2, 7, 3, 26)
+VERSION = (2, 7, 3, 27)
 __version__ = ".".join(map(str, VERSION[0:4])) + "".join(VERSION[4:])
 __author__ = 'R Oudkerk / Python Software Foundation'
 __author_email__ = 'python-dev@python.org'
@@ -94,7 +94,10 @@ def Pipe(duplex=True):
     '''
     Returns two connection object connected by a pipe
     '''
-    from .connection import Pipe
+    if sys.version_info[0] == 3:
+        from multiprocessing.connection import Pipe
+    else:
+        from billiard._connection import Pipe
     return Pipe(duplex)
 
 
