@@ -7,27 +7,27 @@ from time import time
 
 from .exceptions import RestartFreqExceeded
 
-TERMSIGS = frozenset([
-    'HUP',
-    'QUIT',
-    'ILL',
-    'TRAP',
-    'ABRT',
-    'EMT',
-    'FPE',
-    'BUS',
-    'SEGV',
-    'SYS',
-    'PIPE',
-    'ALRM',
-    'TERM',
-    'XCPU',
-    'XFSZ',
-    'VTALRM',
-    'PROF',
-    'USR1',
-    'USR2',
-])
+TERMSIGS = (
+    'SIGHUP',
+    'SIGQUIT',
+    'SIGILL',
+    'SIGTRAP',
+    'SIGABRT',
+    'SIGEMT',
+    'SIGFPE',
+    'SIGBUS',
+    'SIGSEGV',
+    'SIGSYS',
+    'SIGPIPE',
+    'SIGALRM',
+    'SIGTERM',
+    'SIGXCPU',
+    'SIGXFSZ',
+    'SIGVTALRM',
+    'SIGPROF',
+    'SIGUSR1',
+    'SIGUSR2',
+)
 
 
 def _shutdown_cleanup(signum, frame):
@@ -37,10 +37,11 @@ def _shutdown_cleanup(signum, frame):
 def reset_signals(handler=_shutdown_cleanup):
     for sig in TERMSIGS:
         try:
-            signum = getattr(signal, 'SIG%s' % (sig, ))
-            if signal.getsignal(signum) != signal.SIG_IGN:
+            signum = getattr(signal, sig)
+            current = signal.getsignal(signum)
+            if current and current != signal.SIG_IGN:
                 signal.signal(signum, handler)
-        except (AttributeError, ValueError, RuntimeError):
+        except (OSError, AttributeError, ValueError, RuntimeError):
             pass
 
 
